package rkbasic.demo;

import org.robokind.api.animation.Animation;
import org.robokind.api.animation.messaging.RemoteAnimationPlayerClient;
import org.robokind.api.animation.player.AnimationJob;
import org.robokind.api.common.position.NormalizedDouble;
import org.robokind.api.motion.Joint;
import org.robokind.api.motion.Robot.JointId;
import org.robokind.api.motion.Robot.RobotPositionHashMap;
import org.robokind.api.motion.Robot.RobotPositionMap;
import org.robokind.api.motion.messaging.RemoteRobot;
import org.robokind.api.speech.SpeechJob;
import org.robokind.api.speech.messaging.RemoteSpeechServiceClient;
import org.robokind.basic.Robokind;
import org.robokind.basic.RobotJoints;


public class App {

    public static void main(String[] args) {
        
        //Moving
        RemoteRobot robot = Robokind.connectRobot();
        JointId waist = new JointId(robot.getRobotId(), new Joint.Id(RobotJoints.WAIST));
        JointId leg = new JointId(
                robot.getRobotId(), new Joint.Id(RobotJoints.RIGHT_HIP_YAW));

        RobotPositionMap goalPositions = new RobotPositionHashMap();
        goalPositions.put(waist, new NormalizedDouble(1.0));
        goalPositions.put(leg, new NormalizedDouble(0.5));
        
        //Moves the joints to the specified goal positions over 1000 milliseconds
        robot.move(goalPositions, 1000);

        
        //Anims
        RemoteAnimationPlayerClient animPlayer = Robokind.connectAnimationPlayer();
        Animation introAnim = Robokind.loadAnimation("intro.anim.xml");
        AnimationJob introJob = animPlayer.playAnimation(introAnim);
        Robokind.sleep(500 + introJob.getAnimationLength());
        
        
        //Speech
        RemoteSpeechServiceClient speechService = Robokind.connectSpeechService();
        SpeechJob speechJob = speechService.speak("Hello, my name is ZENO.");

        Robokind.disconnect();
        System.exit(0);
    }
}